@@ -58,6 +58,11 @@ fpDrawNormalCI <- function(lower_limit,
                            vertices.height = .1,
                            ...) {
 
+  if (is.na(lower_limit) ||
+      is.na(estimate) ||
+      is.na(upper_limit))
+    return();
+
   # Funciton for drawing the confidence line
   prFpDrawLine(lower_limit = lower_limit,
                upper_limit = upper_limit,
@@ -253,6 +258,11 @@ fpDrawDiamondCI <- function(lower_limit,
                             vertices,
                             vertices.height = .1,
                             ...) {
+  if (is.na(lower_limit) ||
+      is.na(estimate) ||
+      is.na(upper_limit))
+    return();
+
   # Funciton for drawing the confidence line
   prFpDrawLine(lower_limit = lower_limit,
                upper_limit = upper_limit,
@@ -298,6 +308,11 @@ fpDrawCircleCI <- function(lower_limit,
                            vertices,
                            vertices.height = .1,
                            ...) {
+  if (is.na(lower_limit) ||
+      is.na(estimate) ||
+      is.na(upper_limit))
+    return();
+
   # Funciton for drawing the confidence line
   prFpDrawLine(lower_limit = lower_limit,
                upper_limit = upper_limit,
@@ -344,6 +359,11 @@ fpDrawPointCI <- function(lower_limit,
                           vertices.height = .1,
                           pch = 1,
                           ...) {
+  if (is.na(lower_limit) ||
+      is.na(estimate) ||
+      is.na(upper_limit))
+    return();
+
   # Funciton for drawing the confidence line
   prFpDrawLine(lower_limit = lower_limit,
                upper_limit = upper_limit,
@@ -375,11 +395,16 @@ fpDrawPointCI <- function(lower_limit,
 }
 
 #' @rdname fpDrawCI
-#' @param col The color of the summary diamond.
+#' @param col The color of the summary objecct
 #' @export
 fpDrawSummaryCI <- function(lower_limit, estimate, upper_limit,
                             size, col, y.offset = 0.5,
                             ...) {
+  if (is.na(lower_limit) ||
+      is.na(estimate) ||
+      is.na(upper_limit))
+    return();
+
   # Convert size into 'npc' value only if
   # it is provided as a unit() object
   size <- ifelse(is.unit(size),
@@ -392,6 +417,16 @@ fpDrawSummaryCI <- function(lower_limit, estimate, upper_limit,
                          col = col))
 }
 
+#' @rdname fpDrawCI
+#' @export
+fpDrawBarCI <- function (lower_limit, estimate, upper_limit, size, col, y.offset = 0.5, ...)
+{
+  size <- ifelse(is.unit(size), convertUnit(size, unitTo = "npc", valueOnly = TRUE), size) * 0.9
+  grid.polygon(x = unit(c(lower_limit, upper_limit, upper_limit, lower_limit), "native"),
+               y = unit(y.offset + 0.5*c(1, 1, -1, -1)* size, "npc"),
+               gp = gpar(fill = col, col = col))
+}
+
 #' A function for the color elements used in forestplot()
 #'
 #' This function encapsulates all the colors that are used in the
