@@ -14,4 +14,8 @@ test_that("Test that elements are correctly overwritten by the second parameter"
 
   expect_equivalent(prGparMerge(gpar(fill="red", col="red"), gpar(col="black"))$col,
                     "black")
+
+  merged <- prGparMerge(gpar(fill="red", col="red", fontface="bold"), gpar(col="black", fontface="italic"))
+  expect_equivalent(merged[["fontface"]], "italic")
+  expect_null(merged[["font"]])
 })
